| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Sync.MerkleTree.Analyse
Documentation
Arguments
| :: FilePath | Root file path to analyse` |
| -> [String] | List of regular expressions to be excluded from the resulting list |
| -> IO [Entry] | List of file or directory entries with paths relative to the given root |
Returns all files and directories below the given FilePath
isRealFile :: String -> Bool Source
Returns True if the given string is not "." or ".."